@@ -1,13 +1,11 @@
 from datetime import datetime
 import logging
-import os
 import threading
 from time import sleep, time
-import urllib2
 import Pyro4
 import sys
 from pyage.core import inject
-from pyage.core.workspace import Workspace
+from pyage.core.workplace import Workplace
 
 logger = logging.getLogger(__name__)
 
@@ -16,7 +14,7 @@ if __name__ == '__main__':
     logging.basicConfig(filename='pyage-' + str(datetime.now()) + '.log', level=logging.INFO)
     inject.config = sys.argv[1]
     logging.debug("config: %s", inject.config)
-    workspace = Workspace()
+    workspace = Workplace()
     workspace.publish()
     workspace.publish_agents()
     logger.debug(workspace.address)
@@ -33,13 +31,8 @@ if __name__ == '__main__':
     try:
         time = time() - start_time
         logger.debug("elapsed time: %s seconds", time)
-        url = "http://student.agh.edu.pl/~kmaciej/pyage.php?time=%s&agents=%s&conf=%s" % (
-        time, os.environ['AGENTS'], sys.argv[1])
-        logger.debug(url)
-        urllib2.urlopen(url)
     except:
         logger.exception("could not open url")
     workspace.daemon.close()
     workspace.unregister_agents()
-    workspace.unregister()
-
+    workspace.unregister()
\ No newline at end of file
